Crate command_unquoted

Crate command_unquoted 

command-unquoted provides a wrapper struct for std::process::Command that provides a nicer-looking Debug implementation and is useful for logs or user-facing error messages.

Instead of quoting all strings (as done in the Unix Command implementation), quotes are added only where necessary.

As with Command’s Debug implementation, this format only approximates an appropriate shell invocation of the program with the provided environment. It may be particularly unsuitable for Windows (patches welcome). Non-UTF-8 data is lossily converted using the UTF-8 replacement character. This format is not stable and may change between releases; only the API of this crate is stable.

To keep the resulting output friendlier (and sometimes due to Rust standard library limitations), the result of these methods are not displayed in this implementation:

Structs

Unquoted
A wrapper for std::process::Command with a nicer-looking Debug implementation.